/*
 * Copyright 2002-2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package org.springframework.security.saml.provider.config;

import java.util.LinkedList;
import java.util.List;

import org.springframework.security.saml.key.SimpleKey;

import static org.springframework.util.StringUtils.hasText;

public class RotatingKeys {
	private SimpleKey active = null;
	private List<SimpleKey> standBy = new LinkedList<>();

	public List<SimpleKey> toList() {
		LinkedList<SimpleKey> result = new LinkedList<>();
		result.add(getActive());
		result.addAll(getStandBy());
		return result;
	}

	public SimpleKey getActive() {
		return active;
	}

	public RotatingKeys setActive(SimpleKey active) {
		this.active = active;
		if (!hasText(active.getName())) {
			active.setName("active-signing-key");
		}
		return this;
	}

	public List<SimpleKey> getStandBy() {
		return standBy;
	}

	public RotatingKeys setStandBy(List<SimpleKey> standBy) {
		this.standBy = standBy;
		return this;
	}
}
